@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2009-2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2009-2016 -- leonerd@leonerd.org.uk
 
 package Tickit::Widget;
 
@@ -737,21 +737,12 @@ sub redraw
 
 Returns the widget's L<Tickit::Pen>.
 
-Currently this returns a mutable pen, and modifying an attribute of the
-returned object results in the widget being redrawn if the widget has a window
-associated. This behaviour is now deprecated; all style modifications should
-be performed instead using the style system.
-
 =cut
 
 sub pen
 {
    my $self = shift;
 
-   unless( $self->{pen}->mutable ) {
-      $self->_update_pen( $self->{pen}->as_mutable );
-   }
-
    return $self->{pen};
 }
 
@@ -762,14 +753,7 @@ sub _update_pen
 
    return if $self->{pen} and $self->{pen} == $newpen;
 
-   {
-      no warnings 'deprecated';
-
-      $self->{pen}->remove_on_changed( $self ) if $self->{pen} and $self->{pen}->mutable;
-      $self->{pen} = $newpen;
-
-      $newpen->add_on_changed( $self ) if $newpen->mutable;
-   }
+   $self->{pen} = $newpen;
 
    if( $self->window ) {
       $self->window->set_pen( $newpen );
@@ -777,17 +761,6 @@ sub _update_pen
    }
 }
 
-sub on_pen_changed
-{
-   my $self = shift;
-   my ( $pen ) = @_;
-
-   if( $self->window and $pen == $self->{pen} ) {
-      warnings::warnif( deprecated => "Use of Pen mutation is now deprecated" );
-      $self->redraw;
-   }
-}
-
 # Default empty implementation
 sub reshape { }
 
